@@ -13,6 +13,7 @@
 #include "gamgi_gtk.h"
 #include "gamgi_mesa.h"
 #include "gamgi_math.h"
+#include "gamgi_phys.h"
 #include "gamgi_io.h"
 #include "gamgi_expat.h"
 #include "gamgi_global.h"
@@ -1228,6 +1229,8 @@ const char **attributes, gamgi_gml *gml)
 gamgi_cell_class *cell_class;
 gamgi_object *object;
 int fileline, i;
+char token[GAMGI_ENGINE_TOKEN];
+int color = 0;
 
 /**********************************************
  * used only in error messages: file name and *
@@ -1271,10 +1274,279 @@ gml->ml.parent->data = cell_class;
 
 for (i = 0; attributes[i] != NULL; i += 2)
   {
-  return gamgi_io_error_attribute (attributes[i],
+  if (strcmp (attributes[i], "model") == 0)
+    {
+    /*********
+     * reset *
+     *********/
+
+    if (gamgi_io_token_check (attributes[i + 1]) == FALSE)
+      cell_class->model = gamgi->cell->model;
+    
+    /**********
+     * update *
+     **********/
+
+    else if (gamgi_io_token_alpha_scan (attributes[i + 1], token,
+    GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+      return gamgi_io_error_value (attributes[i + 1],
+      gml->ml.filename, fileline, gml->ml.window);
+
+    else if (strcmp (token, "conventional") == 0)
+      cell_class->model = GAMGI_PHYS_CONVENTIONAL;
+    else if (strcmp (token, "primitive") == 0)
+      cell_class->model = GAMGI_PHYS_PRIMITIVE;
+    else if (strcmp (token, "wigner") == 0)
+      cell_class->model = GAMGI_PHYS_WIGNER;
+    else if (strcmp (token, "parallelepiped") == 0)
+      cell_class->model = GAMGI_PHYS_PARALLELEPIPED;
+    else if (strcmp (token, "sphere") == 0)
+      cell_class->model = GAMGI_PHYS_SPHERE;
+    else if (strcmp (token, "projection") == 0)
+      cell_class->model = GAMGI_PHYS_PROJECTION;
+
+    else return gamgi_io_error_value (attributes[i + 1],
+    gml->ml.filename, fileline, gml->ml.window);
+    }
+
+  else if (strcmp (attributes[i], "axes") == 0)
+    {
+    /*********
+     * reset *
+     *********/
+
+    if (gamgi_io_token_check (attributes[i + 1]) == FALSE)
+      cell_class->axes = gamgi->cell->axes;
+
+    /**********
+     * update *
+     **********/
+
+    else if (gamgi_io_token_alpha_scan (attributes[i + 1], token,
+    GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+      return gamgi_io_error_value (attributes[i + 1],
+      gml->ml.filename, fileline, gml->ml.window);
+
+    else if (strcmp (token, "yes") == 0)
+      cell_class->axes = TRUE;
+    else if (strcmp (token, "no") == 0)
+      cell_class->axes = FALSE;
+
+    else return gamgi_io_error_value (attributes[i + 1],
+    gml->ml.filename, fileline, gml->ml.window);
+    }
+
+  else if (strcmp (attributes[i], "borders") == 0)
+    {
+    /*********
+     * reset *
+     *********/
+
+    if (gamgi_io_token_check (attributes[i + 1]) == FALSE)
+      cell_class->borders = gamgi->cell->borders;
+
+    /**********
+     * update *
+     **********/
+
+    else if (gamgi_io_token_alpha_scan (attributes[i + 1], token,
+    GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE)
+      return gamgi_io_error_value (attributes[i + 1],
+      gml->ml.filename, fileline, gml->ml.window);
+
+    else if (strcmp (token, "all") == 0)
+      cell_class->borders = GAMGI_PHYS_ALL;
+    else if (strcmp (token, "faces") == 0)
+      cell_class->borders = GAMGI_PHYS_FACES;
+    else if (strcmp (token, "edges") == 0)
+      cell_class->borders = GAMGI_PHYS_EDGES;
+    else if (strcmp (token, "none") == 0)
+      cell_class->borders = GAMGI_PHYS_NONE;
+
+    else return gamgi_io_error_value (attributes[i + 1],
+    gml->ml.filename, fileline, gml->ml.window);
+    }
+
+  /****************
+   * nodes, faces *
+   ****************/
+
+  else if (strcmp (attributes[i], "faces") == 0)
+    {
+    /*********
+     * reset *
+     *********/
+
+    if (gamgi_io_token_check (attributes[i + 1]) == FALSE)
+      cell_class->faces = gamgi->cell->faces;
+
+    /**********
+     * update *
+     **********/
+
+    else if (gamgi_io_token_bool_scan (attributes[i + 1], &cell_class->faces) == FALSE)
+      return gamgi_io_error_value (attributes[i + 1],
+      gml->ml.filename, fileline, gml->ml.window);
+
+    }
+
+  else if (strcmp (attributes[i], "nodes") == 0)
+    {
+    /*********
+     * reset *
+     *********/
+
+    if (gamgi_io_token_check (attributes[i + 1]) == FALSE)
+      cell_class->nodes = gamgi->cell->nodes;
+
+    /**********
+     * update *
+     **********/
+
+    else if (gamgi_io_token_bool_scan (attributes[i + 1], &cell_class->nodes) == FALSE)
+      return gamgi_io_error_value (attributes[i + 1],
+      gml->ml.filename, fileline, gml->ml.window);
+    }
+
+  /******************
+   * red,green,blue *
+   ******************/
+
+  else if (strcmp (attributes[i], "red") == 0)
+    {
+    color++;
+
+    /*********
+     * reset *
+     *********/
+
+    if (gamgi_io_token_check (attributes[i + 1]) == FALSE)
+      cell_class->red = -2.0;
+
+    /**********
+     * update *
+     **********/
+
+    else if (gamgi_io_token_float_scan (attributes[i + 1],
+    &cell_class->red, 0.0, 1.0) == FALSE)
+      return gamgi_io_error_value (attributes[i + 1],
+      gml->ml.filename, fileline, gml->ml.window);
+    }
+
+  else if (strcmp (attributes[i], "green") == 0)
+    {
+    color++;
+
+    /*********
+     * reset *
+     *********/
+
+    if (gamgi_io_token_check (attributes[i + 1]) == FALSE)
+      cell_class->green = -2.0;
+
+    /**********
+     * update *
+     **********/
+
+    else if (gamgi_io_token_float_scan (attributes[i + 1],
+    &cell_class->green, 0.0, 1.0) == FALSE)
+      return gamgi_io_error_value (attributes[i + 1],
+      gml->ml.filename, fileline, gml->ml.window);
+    }
+
+  else if (strcmp (attributes[i], "blue") == 0)
+    {
+    color++;
+
+    /*********
+     * reset *
+     *********/
+
+    if (gamgi_io_token_check (attributes[i + 1]) == FALSE)
+      cell_class->blue = -2.0;
+
+    /**********
+     * update *
+     **********/
+
+    else if (gamgi_io_token_float_scan (attributes[i + 1],
+    &cell_class->blue, 0.0, 1.0) == FALSE)
+      return gamgi_io_error_value (attributes[i + 1],
+      gml->ml.filename, fileline, gml->ml.window);
+    }
+
+  else if (strcmp (attributes[i], "axes_size") == 0)
+    {
+    /*********
+     * reset *
+     *********/
+
+    if (gamgi_io_token_check (attributes[i + 1]) == FALSE)
+      cell_class->axes_size = gamgi->cell->axes_size;
+
+    /**********
+     * update *
+     **********/
+
+    else if (gamgi_io_token_float_scan (attributes[i + 1],
+    &cell_class->axes_size, GAMGI_MESA_AXES_MIN,
+    GAMGI_MESA_AXES_MAX) == FALSE)
+      return gamgi_io_error_value (attributes[i + 1],
+      gml->ml.filename, fileline, gml->ml.window);
+    }
+
+  else if (strcmp (attributes[i], "borders_width") == 0)
+    {
+    /*********
+     * reset *
+     *********/
+
+    if (gamgi_io_token_check (attributes[i + 1]) == FALSE)
+      cell_class->borders_width = gamgi->cell->borders_width;
+
+    /**********
+     * update *
+     **********/
+
+    else if (gamgi_io_token_int_scan (attributes[i + 1],
+    &cell_class->borders_width, GAMGI_MESA_CELL_LINE_MIN,
+    GAMGI_MESA_CELL_LINE_MAX) == FALSE)
+      return gamgi_io_error_value (attributes[i + 1],
+      gml->ml.filename, fileline, gml->ml.window);
+    }
+
+  else if (strcmp (attributes[i], "nodes_width") == 0)
+    {
+    /*********
+     * reset *
+     *********/
+
+    if (gamgi_io_token_check (attributes[i + 1]) == FALSE)
+      cell_class->nodes_width = gamgi->cell->nodes_width;
+
+    /**********
+     * update *
+     **********/
+
+    else if (gamgi_io_token_int_scan (attributes[i + 1],
+    &cell_class->nodes_width, GAMGI_MESA_CELL_POINT_MIN,
+    GAMGI_MESA_CELL_POINT_MAX) == FALSE)
+      return gamgi_io_error_value (attributes[i + 1],
+      gml->ml.filename, fileline, gml->ml.window);
+    }
+
+  else return gamgi_io_error_attribute (attributes[i],
   gml->ml.filename, fileline, gml->ml.window);
   }
 
+/***********************************
+ * global: incompatible attributes *
+ ***********************************/
+
+if (color == 1 || color == 2)
+  return gamgi_io_error_incompatible (gml->ml.filename,
+  fileline, gml->ml.window);
+
 return gml->ml.valid;
 }
 
