@@ -192,10 +192,16 @@ static_translation_remove (window);
 translation.base = NULL;
 }
 
-static void static_translation_delete (GtkWidget *widget, 
+static int static_translation_delete (GtkWidget *widget, 
 GdkEventButton *event, void *data)
 {
 static_translation_cancel (widget, data);
+
+/*************************
+ * FALSE: destroy window *
+ *************************/
+
+return FALSE;
 }
 
 static void static_translation_layer (gamgi_window *window)
@@ -841,10 +847,16 @@ static_rotation_remove (window);
 rotation.base = NULL;
 }
 
-static void static_rotation_delete (GtkWidget *widget, 
+static int static_rotation_delete (GtkWidget *widget, 
 GdkEventButton *event, void *data)
 {
 static_rotation_cancel (widget, data);
+
+/*************************
+ * FALSE: destroy window *
+ *************************/
+
+return FALSE;
 }
 
 static void static_rotation_label (gamgi_window *window)
