@@ -531,10 +531,10 @@ gamgi_global_selection_focus ();
 
 if (cache.above == TRUE)
   {
-  /*******************************
-   * link each listed cluster to *
-   * the parent selected object  *
-   *******************************/
+  /*******************************************
+   * link above: link each listed cluster    *
+   * (child) to the selected object (parent) *
+   *******************************************/
 
   parent = cache.object;
   layer_parent = gamgi_engine_find_layer (parent);
@@ -560,13 +560,12 @@ if (cache.above == TRUE)
   window_parent = GAMGI_CAST_WINDOW layer_parent->object.object;
   gamgi_gtk_object_raise (layer_parent, window_parent);
   } 
-
-if (cache.above == FALSE)
+else
   {
-  /******************************************
-   * link each listed cluster to a child    *
-   * object copied from the selected object *
-   ******************************************/
+  /****************************************************
+   * link below: link each listed cluster (parent) to *
+   * a child object copied from the selected object   *
+   ****************************************************/
 
   child = cache.object;
 
@@ -622,6 +621,11 @@ if (cluster == NULL)
 
 if (static_grab (window_dialog) == FALSE) return;
 
+/*************************************************************************
+ * link above: link selected cluster (child) to selected object (parent) *
+ * link below: link selected cluster (parent) to selected object (child) *
+ *************************************************************************/
+
 if (cache.above == TRUE)
   { child = GAMGI_CAST_OBJECT cluster; parent = cache.object; }
 else
