@@ -512,10 +512,10 @@ gamgi_global_selection_focus ();
 
 if (cache.above == TRUE)
   {
-  /*******************************
-   * link each listed orbital to *
-   * the parent selected object  *
-   *******************************/
+  /*******************************************
+   * link above: link each listed orbital    *
+   * (child) to the selected object (parent) *
+   *******************************************/
 
   parent = cache.object;
   layer_parent = gamgi_engine_find_layer (parent);
@@ -541,13 +541,12 @@ if (cache.above == TRUE)
   window_parent = GAMGI_CAST_WINDOW layer_parent->object.object;
   gamgi_gtk_object_raise (layer_parent, window_parent);
   }
-
-if (cache.above == FALSE)
+else
   {
-  /******************************************
-   * link each listed orbital to a child    *
-   * object copied from the selected object *
-   ******************************************/
+  /****************************************************
+   * link below: link each listed orbital (parent) to *
+   * a child object copied from the selected object   *
+   ****************************************************/
 
   child = cache.object;
 
@@ -603,6 +602,11 @@ if (orbital == NULL)
 
 if (static_grab (window_dialog) == FALSE) return;
 
+/*************************************************************************
+ * link above: link selected orbital (child) to selected object (parent) *
+ * link below: link selected orbital (parent) to selected object (child) *
+ *************************************************************************/
+
 if (cache.above == TRUE)
   { child = GAMGI_CAST_OBJECT orbital; parent = cache.object; }
 else
