@@ -523,10 +523,10 @@ gamgi_global_selection_focus ();
 
 if (cache.above == TRUE)
   {
-  /******************************
-   * link each listed plane to  *
-   * the parent selected object *
-   ******************************/
+  /*******************************************
+   * link above: link each listed plane      *
+   * (child) to the selected object (parent) *
+   *******************************************/
 
   parent = cache.object;
   layer_parent = gamgi_engine_find_layer (parent);
@@ -552,13 +552,12 @@ if (cache.above == TRUE)
   window_parent = GAMGI_CAST_WINDOW layer_parent->object.object;
   gamgi_gtk_object_raise (layer_parent, window_parent);
   } 
-
-if (cache.above == FALSE)
+else
   {
-  /******************************************
-   * link each listed plane to a child      *
-   * object copied from the selected object *
-   ******************************************/
+  /**************************************************
+   * link below: link each listed plane (parent) to *
+   * a child object copied from the selected object *
+   **************************************************/
 
   child = cache.object;
 
@@ -613,6 +612,11 @@ if (plane == NULL)
 
 if (static_grab (window_dialog) == FALSE) return;
 
+/***********************************************************************
+ * link above: link selected plane (child) to selected object (parent) *
+ * link below: link selected plane (parent) to selected object (child) *
+ ***********************************************************************/
+
 if (cache.above == TRUE)
   { child = GAMGI_CAST_OBJECT plane; parent = cache.object; }
 else
