@@ -207,6 +207,109 @@ static void static_orbital (FILE *fp, gamgi_orbital *orbital,
 gamgi_bool lights, gamgi_bool *error)
 {
 gamgi_dlist *dlist;
+int *dots;
+char string[GAMGI_ENGINE_LINE];
+double axis[3];
+double phi;
+float background[4];
+float color[3];
+
+/****************************
+ * scale, translate, rotate *
+ ****************************/
+
+static_scale (fp, orbital->object.scale, orbital->center, error);
+
+gamgi_math_quaternion_to_axis (orbital->quaternion, &phi, axis);
+
+sprintf (string, "<Transform translation=\"%.*f %.*f %.*f\" rotation=\"%.*f %.*f %.*f %.*f\">\n",
+gamgi->gamgi->length, orbital->origin[0],
+gamgi->gamgi->length, orbital->origin[1],
+gamgi->gamgi->length, orbital->origin[2],
+gamgi->gamgi->length, axis[0],
+gamgi->gamgi->length, axis[1],
+gamgi->gamgi->length, axis[2],
+gamgi->gamgi->angle, phi);
+gamgi_io_file_fprintf (fp, string, error);
+
+glGetFloatv (GL_COLOR_CLEAR_VALUE, background);
+
+dots = orbital->dots;
+if (orbital->style == GAMGI_MESA_WIRED)
+  {
+  glLineWidth (4.0);
+  if (dots[1] > 0)
+    { 
+    color[0] = orbital->base_r;
+    color[1] = orbital->base_g;
+    color[2] = orbital->base_b;
+    gamgi_io_x3d_render_points (fp, dots[1],
+    orbital->points + 3 * dots[0], color, error);
+    }
+
+  if (dots[2] > 0)
+    {
+    color[0] = orbital->phase_r;
+    color[1] = orbital->phase_g;
+    color[2] = orbital->phase_b;
+    gamgi_io_x3d_render_points (fp, dots[2],
+    orbital->points + 3 * dots[0] + 3 * dots[1], color, error);
+    }
+  }
+
+if (orbital->style == GAMGI_MESA_SOLID)
+  {
+  if (dots[1] > 0)
+    {
+    gamgi_io_file_fprintf (fp, "<Shape>\n<Appearance>\n", error);
+
+    if (lights == TRUE)
+      sprintf (string, "<Material diffuseColor=\"%.*f %.*f %.*f\"/>\n",
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_r,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_g,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_b);
+    else
+      sprintf (string, "<Material emissiveColor=\"%.*f %.*f %.*f\"/>\n",
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_r,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_g,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->base_b);
+    gamgi_io_file_fprintf (fp, string, error);
+    gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
+
+    gamgi_io_x3d_render_triangles (fp, dots[1] / 3,
+    orbital->points + 3 * dots[0], error);
+    gamgi_io_file_fprintf (fp, "</Shape>\n", error);
+    }
+
+  if (dots[2] > 0)
+    {
+    gamgi_io_file_fprintf (fp, "<Shape>\n<Appearance>\n", error);
+
+    if (lights == TRUE)
+      sprintf (string, "<Material diffuseColor=\"%.*f %.*f %.*f\"/>\n",
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_r,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_g,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_b);
+    else
+      sprintf (string, "<Material emissiveColor=\"%.*f %.*f %.*f\"/>\n",
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_r,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_g,
+      GAMGI_MATH_DECIMAL_COLOR, orbital->phase_b);
+    gamgi_io_file_fprintf (fp, string, error);
+    gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
+
+    gamgi_io_x3d_render_triangles (fp, dots[2] / 3,
+    orbital->points + 3 * dots[0] + 3 * dots[1], error);
+    gamgi_io_file_fprintf (fp, "</Shape>\n", error);
+    }
+     
+  }
+
+/******************************
+ * end Shape, Transform nodes *
+ ******************************/
+
+gamgi_io_file_fprintf (fp, "</Transform>\n", error);
 
 /***********************
  * child objects: text *
@@ -214,6 +317,8 @@ gamgi_dlist *dlist;
 
 for (dlist = orbital->text_start; dlist!=NULL; dlist = dlist->next)
   static_text (fp, GAMGI_CAST_TEXT dlist->data, lights, error);
+
+static_unscale (fp, orbital->object.scale, error);
 }
 
 static void static_bond (FILE *fp, gamgi_bond *bond, gamgi_atom *atom, 
@@ -518,7 +623,7 @@ static void static_direction (FILE *fp, gamgi_direction *direction,
 gamgi_bool lights, gamgi_bool *error)
 {
 gamgi_dlist * dlist;
-char string[256];
+char string[GAMGI_ENGINE_LINE];
 double axis[3];
 double phi;
 float color[3];
@@ -994,7 +1099,7 @@ static void static_cell (FILE *fp, gamgi_cell *cell,
 gamgi_bool lights, gamgi_bool *error)
 {
 gamgi_dlist * dlist;
-char string[256];
+char string[GAMGI_ENGINE_LINE];
 double axis[3];
 double phi;
 float background[4];
@@ -1056,7 +1161,7 @@ if (cell->loops != NULL && cell->borders != FALSE &&
   gamgi_io_file_fprintf (fp, string, error);
 		
   sprintf (string, "<LineProperties linewidthScaleFactor=\"%.*f\"/>\n", 
-  GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_CELL_WIDTH);
+  GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_CELL_LINE);
   gamgi_io_file_fprintf (fp, string, error);
   gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
 		
@@ -1088,7 +1193,7 @@ if (cell->lines != NULL)
   gamgi_io_file_fprintf (fp, string, error);
 
   sprintf (string, "<LineProperties linewidthScaleFactor=\"%.*f\"/>\n", 
-  GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_CELL_WIDTH);
+  GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_CELL_LINE);
   gamgi_io_file_fprintf (fp, string, error);
   gamgi_io_file_fprintf (fp, "</Appearance>\n", error);
 
@@ -1361,24 +1466,30 @@ gamgi_io_file_fprintf (fp, "<Scene>\n", error);
  *                                                             *
  * Possible values are: WALK, FLY, EXAMINE, LOOKAT, ANY, NONE  *
  * values can be combined, for example: type='"EXAMINE" "ANY"' *
+ *                                                             *
+ * Apparently, the GAMGI OpenGL lightning seems to be slightly *
+ * better simulated in X3D when global is set to false, which  *
+ * means that lights apply only to the local node.             *
  ***************************************************************/
 
 gamgi_io_file_fprintf (fp, "<NavigationInfo headlight=\"false\""
 " type=\"ANY\"/>\n", error);
 
+gamgi_io_file_fprintf (fp, "<DirectionalLight global=\"false\"/>\n", error);
+
 /**************
  * projection *
  **************/
 
 if (layer->perspective == TRUE)
   {
-  gamgi_io_file_fprintf (fp, "<Viewpoint description=\"gamgi\"", error);
-  sprintf (string, " fieldOfView=\"%.*f\"", 
+  gamgi_io_file_fprintf (fp, "<Viewpoint description=\"perspective\"", error);
+  sprintf (string, " fieldOfView=\"%.*f\"\n", 
   gamgi->gamgi->length, 2.0 * atan ((2.0 * layer->top) * 0.5 / layer->near));
   }
 else
   {
-  gamgi_io_file_fprintf (fp, "<OrthoViewpoint description=\"gamgi\"", error);
+  gamgi_io_file_fprintf (fp, "<OrthoViewpoint description=\"orthographic\"", error);
   sprintf (string, " fieldOfView=\"%.*f %.*f %.*f %.*f\"", 
   gamgi->gamgi->length, -layer->top, 
   gamgi->gamgi->length, -layer->top, 
@@ -1393,7 +1504,7 @@ gamgi_io_file_fprintf (fp, string, error);
 
 gamgi_math_vector_sub (layer->eye, layer->center, normal);
 gamgi_math_vector_normal (normal);
-sprintf (string, " orientation=\"%.*f %.*f %.*f %.*f\"", 
+sprintf (string, "orientation=\"%.*f %.*f %.*f %.*f\"", 
 gamgi->gamgi->length, normal[0], 
 gamgi->gamgi->length, normal[1], 
 gamgi->gamgi->length, normal[2],
