@@ -357,6 +357,45 @@ while (n_lines-- > 0)
 gamgi_io_file_fprintf(fp, "'/>\n</IndexedLineSet>\n", error);
 }
 
+/************* external function ***********
+ *                                         *
+ *      GAMGI_IO_X3D_RENDER_TRIANGLES      *
+ *                                         *
+ *       render a triangle-based face      *
+ *******************************************/
+
+void gamgi_io_x3d_render_triangles (FILE *fp,
+int n_triangles, double *points, gamgi_bool *error)
+{
+char string[GAMGI_ENGINE_LINE];
+int n_points, i;
+
+if (n_triangles == 0) return;
+n_points = 3 * n_triangles;
+
+gamgi_io_file_fprintf (fp, "<IndexedTriangleSet ", error);
+gamgi_io_file_fprintf (fp, "solid=\"false\" ", error);
+gamgi_io_file_fprintf (fp, "ccw=\"true\" ", error);
+gamgi_io_file_fprintf (fp, "normalPerVertex=\"false\" ", error);
+gamgi_io_file_fprintf (fp, "index=\"\n", error);
+
+for (i = 0; i < n_points; i += 3)
+  {
+  sprintf (string, "%d %d %d\n", i + 0, i + 1, i + 2);
+  gamgi_io_file_fprintf (fp, string, error);
+  }
+gamgi_io_file_fprintf (fp, "\">\n<Coordinate point=\"\n", error);
+
+for (i = 0; i < n_points; i++)
+  {
+  sprintf (string, "%f %f %f\n",
+  points[3 * i + 0], points[3 * i + 1] + 10, points[3 * i + 2]);
+  gamgi_io_file_fprintf (fp, string, error);
+  }
+
+gamgi_io_file_fprintf (fp, "\"/>\n</IndexedTriangleSet>\n", error);
+}
+
 /************* external function ***********
  *                                         *
  *      GAMGI_IO_X3D_RENDER_LINE_STRIP     *
