@@ -131,7 +131,7 @@ if (orbital->frame == TRUE)
   { glColor3f (orbital->frame_r, orbital->frame_g, orbital->frame_b);
     gamgi_mesa_render_lines (orbital->lines, orbital->points); }
 if (orbital->axes != GAMGI_CHEM_NONE)
-  gamgi_mesa_axes_orbital (orbital, TRUE);
+  gamgi_mesa_axes_orbital (orbital, TRUE, GAMGI_MESA_AXES_SIZE);
 
 /******************
  * draw text list *
@@ -817,8 +817,8 @@ if (cell->model != GAMGI_PHYS_PROJECTION)
 
 glColor3f (cell->red,  cell->green, cell->blue);
 
-glLineWidth (GAMGI_MESA_CELL_WIDTH);
-glPointSize (GAMGI_MESA_CELL_POINT);
+glLineWidth (gamgi->cell->borders_width);
+glPointSize (gamgi->cell->nodes_width);
 
 if (cell->faces == TRUE)
   {
@@ -839,7 +839,7 @@ if (cell->faces == TRUE)
 if (cell->lines != NULL)
   gamgi_mesa_render_lines (cell->lines, cell->points);
 
-if (cell->loops != NULL && cell->borders != FALSE &&
+if (cell->loops != NULL && cell->borders != GAMGI_PHYS_NONE &&
 (cell->lattice != GAMGI_PHYS_HEXAGONAL_P ||
 (cell->model != GAMGI_PHYS_WIGNER && cell->model != GAMGI_PHYS_CONVENTIONAL)) &&
 (cell->lattice != GAMGI_PHYS_ORTHORHOMBIC_C || cell->model != GAMGI_PHYS_WIGNER))
@@ -856,7 +856,8 @@ glPointSize (1.0);
  * draw axes *
  *************/
 
-if (cell->axes == TRUE) gamgi_mesa_axes_cell (cell, TRUE);
+if (cell->axes == TRUE)
+  gamgi_mesa_axes_cell (cell, TRUE, gamgi->cell->axes_size);
 
 glPopMatrix ();
 
@@ -1207,7 +1208,8 @@ glTranslatef (-layer->center[0], -layer->center[1], -layer->center[2]);
  * draw axes *
  *************/
 
-if (layer->axes == TRUE) gamgi_mesa_axes_layer (layer, TRUE);
+if (layer->axes == TRUE)
+  gamgi_mesa_axes_layer (layer, TRUE, GAMGI_MESA_AXES_SIZE);
 
 dlist = layer->assembly_start;
 while (dlist != NULL)
