@@ -194,7 +194,7 @@ if (class >= GAMGI_ENGINE_ORBITAL)
   if (orbital->frame == TRUE)
     gamgi_mesa_render_lines (orbital->lines, orbital->points);
   if (orbital->axes != GAMGI_CHEM_NONE)
-    gamgi_mesa_axes_orbital (orbital, FALSE);
+    gamgi_mesa_axes_orbital (orbital, FALSE, GAMGI_MESA_AXES_SIZE);
 
   glPopMatrix ();
   }
@@ -1275,8 +1275,8 @@ if (class >= GAMGI_ENGINE_CELL)
     glMultMatrixd (rotate);
     }
 
-  glLineWidth (GAMGI_MESA_CELL_WIDTH);
-  glPointSize (GAMGI_MESA_CELL_WIDTH);
+  glLineWidth (gamgi->cell->borders_width);
+  glPointSize (gamgi->cell->nodes_width);
 
   if (cell->faces == TRUE)
     {
@@ -1294,7 +1294,7 @@ if (class >= GAMGI_ENGINE_CELL)
   if (cell->lines != NULL)
     gamgi_mesa_render_lines (cell->lines, cell->points);
 
-  if (cell->loops != NULL && cell->borders != FALSE &&
+  if (cell->loops != NULL && cell->borders != GAMGI_PHYS_NONE &&
   (cell->lattice != GAMGI_PHYS_HEXAGONAL_P ||
   (cell->model != GAMGI_PHYS_WIGNER && cell->model != GAMGI_PHYS_CONVENTIONAL)) &&
   (cell->lattice != GAMGI_PHYS_ORTHORHOMBIC_C || cell->model != GAMGI_PHYS_WIGNER))
@@ -1311,7 +1311,8 @@ if (class >= GAMGI_ENGINE_CELL)
    * draw axes *
    *************/
 
-  if (cell->axes == TRUE) gamgi_mesa_axes_cell (cell, FALSE);
+  if (cell->axes == TRUE)
+    gamgi_mesa_axes_cell (cell, FALSE, gamgi->cell->axes_size);
 
   glPopMatrix ();
   }
